# Security Policy

## Supported Versions

| Version  | Supported          |
| -------- | ------------------ |
| 3.1.x    | :white_check_mark: |
| 3.0.x    | :x:                |

## Reporting a Vulnerability

Please report security issues by e-mail to breezy-core@googlegroups.com.
